# TOPSIS
Technique for Order Preference by Similarity to Ideal Solution is a multi-criteria decision making method. The method is based on finding an ideal and an anti-ideal solution and comparing the distance of each one of the alternatives to those. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution.
## Package Usage
To install the package:
pip install Topsis_Samridhi_101916086
This is a package focusing on finding the topsis score and rank of a dataframe (csv file) with only numerical values except for the first column.
## OUTPUT
The python file consists of the logic which excepts 4 parameter:
1. Input csv file
2. Weights given by user comma separted
3. Impact given by user comma separated
4. Result csv file, just to restore the naming convention.. result file will contain 2 additional columns contianing topsis_score and rank
## LICENSE
Copyright (c) 2022 Samridhi Garg